@@ -5,6 +5,7 @@ from github import Github
 from datetime import datetime
 from .config_access import set_token, get_token, get_remote_name, make_encryption_key, get_encryption_key, get_config_file, make_empty_config, remove_encryption_key
 import time
+from tqdm import tqdm
 from multiprocessing.pool import ThreadPool
 from cryptography.fernet import Fernet
 
@@ -57,6 +58,19 @@ def fetch(datestring):
     user = g.get_user()
     repo = user.get_repo(get_remote_name())
     try:
+        contents = repo.get_contents("entries/" + datestring)
+        # Count number of files; This takes about half a second for 20 files
+        file_count = 0
+        while contents:
+            file_content = contents.pop(0)
+            if file_content.type == "dir":
+                contents.extend(repo.get_contents(file_content.path))
+            else:
+                file_count += 1
+
+        # initialize progress bar
+        pbar = tqdm(total=file_count)
+        # Get file contents and add to output_lines
         contents = repo.get_contents("entries/" + datestring)
         while contents:
             file_content = contents.pop(0)
@@ -67,7 +81,9 @@ def fetch(datestring):
                 if get_encryption_key() != '':
                     log_contents = decrypt_text(log_contents)
                 output_lines.append(log_contents)
+                pbar.update(1)
         output = '\n'.join(output_lines)
+        pbar.close()
     except Exception:
         output = "No entries found for specified day(s)"
     print(output)
